package com.efaxdeveloper.util.outbound;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;

/**
 * <p><b>DispositionCatcherServlet (Sample code)</b></p>
 * <p><b>Overview</b></p>
 * <blockquote>
 * <p>This servlet class is provided as sample code for final disposition processing.</p>
 * </blockquote>
 */
public class DispositionCatcherServlet extends HttpServlet {
  private static final long serialVersionUID = 7411312642829793198L;
  private static final String CONTENT_TYPE = "text/html";

  /**Initialize global variables*/
  public void init(ServletConfig config) throws ServletException {
    super.init(config);
  }

  public void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
    doPost(request, response);
  }
  
  public void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
    
    response.setContentType(CONTENT_TYPE);
    PrintWriter out = response.getWriter();
    
    out.println("<html>");
    out.println("<head><title>DispositionCatcherServlet</title></head>");
    out.println("<body>");
    
    // Retrieve the disposition "xml" parameter value from the request
    String xml = request.getParameter("xml");
    
    // The following StringBuilder is provided as a sample and can be fed to the DispositionCatcher to see how it works.
    // In reality, the "xml" parameter value retrieved from the POST request would be fed to the DispositionCatcher.
    StringBuilder sb = new StringBuilder("<OutboundDisposition UserName=\"aaa\" Password=\"aaa\" TransmissionID=\"1000\"");
    sb.append(" DOCID=\"15642373\" FaxNumber=\"9999999999\" CompletionDate=\"2003-05-19 13:18:08\" FaxStatus=\"0\"");
    sb.append(" RecipientCSID=\"MJC Inbound\" Duration=\"0.8\" PagesSent=\"2\" NumberOfRetries=\"1\"/>");
    
    try {
      // Establish a DispositionCatcher object (change to pass the StringBuilder sample if desired)
      DispositionCatcher dc = new DispositionCatcher(xml);
      // When the disposition's username and password validates successfully
      if (isValid(dc)) {
        // Process the disposition as desired
        processDisposition(dc, out);
      }
    }
    catch (Exception e) {
      e.printStackTrace();
      e.printStackTrace(out);
    }
    catch (Error err) {
      err.printStackTrace();
      err.printStackTrace(out);
    }
    finally {
      out.println("</body></html>");
      out.flush();
      out.close();
    }
    
  }
  
  private boolean isValid(DispositionCatcher dc) {
    // Logic would be added here to validate the userName and password
    // against a client database for additional security if desired.
    return true;
  }
  
  private void processDisposition(DispositionCatcher dc, PrintWriter out) throws Exception {
    
    try {
      // Retrieve the final disposition data. Client processing will likely 
      // write the disposition data to a transaction database instead of
      // displaying it to terminal output as the following example shows.
      System.out.println("");
      System.out.println("------------------------------------");
      System.out.println("UserName: "        + dc.getUserName());
      System.out.println("Password: "        + dc.getPassword());
      System.out.println("TransmissionID: "  + dc.getTransmissionID());
      System.out.println("DOCID: "           + dc.getDOCID());
      System.out.println("FaxNumber: "       + dc.getFaxNumber());
      System.out.println("CompletionDate: "  + dc.getCompletionDate());
      System.out.println("FaxStatus: "       + dc.getFaxStatus());
      System.out.println("RecipientCSID: "   + dc.getRecipientCSID());
      System.out.println("Duration: "        + dc.getDuration());
      System.out.println("PagesSent: "       + dc.getPagesSent());
      System.out.println("NumberOfRetries: " + dc.getNumberOfRetries());
      System.out.println("------------------------------------");
      // Reply back to eFax Developer indicating that the final disposition
      // has been successfully received by your processing.
      out.println("Post Successful");
    }
    catch (Exception e) {
      throw e;
    }
    catch (Error err) {
      throw err;
    }
    
  }
  
  public void destroy() {
  }
  
}