package com.efaxdeveloper.util.outbound;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
 * <p><b>StatusRequestServlet (Sample code)</b></p>
 * <p><b>Overview</b></p>
 * <blockquote>
 * <p>This servlet class is provided as sample code for outbound status request processing.</p>
 * </blockquote>
 */
public class StatusRequestServlet extends HttpServlet {
  private static final long serialVersionUID = -3588644466431151495L;
  private static final String CONTENT_TYPE = "text/html";

  /**Initialize global variables*/
  public void init(ServletConfig config) throws ServletException {
    super.init(config);
  }

  public void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
    
    response.setContentType(CONTENT_TYPE);
    PrintWriter out = response.getWriter();
    
    // Instantiate a new StatusRequest object
    StatusRequest req = new StatusRequest();
    
    /*----------------------------------------------------------------*/
    /*----------------- Set response type ----------------------------*/
    /*----------------------------------------------------------------*/
    // Set your desired response type (XML response is default)
    req.setHTMLResponse(false);
    
    /*----------------------------------------------------------------*/
    /*----------------- Set user identification ----------------------*/
    /*----------------------------------------------------------------*/
    // Set your eFax Developer outbound account identifier (required)
    req.setAccountID("");
    // Set your eFax Developer outbound user name (required)
    req.setUserName("");
    // Set your eFax Developer outbound password (required)
    req.setPassword("");

    /*----------------------------------------------------------------*/
    /*----------------- Set your search values -----------------------*/
    /*----------------------------------------------------------------*/
    // Search by your transmission identifier
    req.setTransmissionID("");
    // Search by eFax Developer's transmission identifier
    req.setDOCID("");
    
    try {
      // Retrieve the transmission status from eFax Developer
      StatusResponse resp = req.getStatus();
      // When an XML response is selected (default)
      if (!resp.isHTMLResponse()) {
        // Process the XML response
        processXMLResponse(resp, out);
      }
      // Otherwise, an HTML response is desired
      else {
        // Process the HTML response
        processHTMLResponse(resp, out);
      }
    }
    catch (Exception e) {
      e.printStackTrace(); 
    }
    catch (Error err) {
      err.printStackTrace();
    }
    finally {
      out.flush();
      out.close();
    }
    
  }

  private void processHTMLResponse(StatusResponse resp, PrintWriter out) {
    
    // Retrieve the raw response
    out.println(resp.getRawResponse());
    
  }
  
  private void processXMLResponse(StatusResponse resp, PrintWriter out) {
    
    out.println("<html>");
    out.println("<head><title>StatusRequestServlet</title></head>");
    out.println("<body>");
    
    // When eFax Developer approved the status request
    if (resp.isApproved()) {
      out.println("<p>eFax Developer&trade; received your request and returned the following response:</p>");
      out.println("<blockquote>");
      out.println("<p>Status response for transmission ID: " + resp.getTransmissionID());
      out.println("</p>");
      out.println(resp.getMessage());
      out.println("<blockquote>");
      out.println("<br>DOC Identifier: "        + resp.getDocID());
      // When a client specified customer identifier is used
      if ((resp.getCustomerID() != null) && (resp.getCustomerID().trim().length() > 0)) {
        out.println("<br>Customer ID: "         + resp.getCustomerID());
      }
      out.println("<br>Fax Number: "            + resp.getRecipientFax());
      out.println("<br>Recipient: "             + resp.getRecipientName());
      out.println("<br>Company: "               + resp.getRecipientCompany());
      out.println("<br>Status Classification: " + resp.getClassification());
      out.println("<br>Status Outcome: "        + resp.getOutcome());
      out.println("<br>Last Attempt Date: "     + resp.getLastDate());
      out.println("<br>Last Attempt Time: "     + resp.getLastTime());
      out.println("<br>Next Attempt Date: "     + resp.getNextDate());
      out.println("<br>Next Attempt Time: "     + resp.getNextTime());
      out.println("<br>Pages Scheduled: "       + resp.getPagesScheduled());
      out.println("<br>Pages Sent: "            + resp.getPagesSent());
      out.println("<br>Baud Rate: "             + resp.getBaudRate());
      out.println("<br>Duration (in minutes): " + resp.getDuration());
      out.println("<br>Number of Retries: "     + resp.getRetries());
      out.println("<br>Remote CSID: "           + resp.getRemoteCSID());
      out.println("</blockquote>");
      out.println("</blockquote>");
    }
    // Otherwise, eFax Developer rejected the status request
    else {
      out.println("<p>eFax Developer&trade; received your status request but encountered an error</p>");
      out.println("<blockquote>");
      // When searching by the client transmission identifier
      if ((resp.getTransmissionID() != null) && (resp.getTransmissionID().length() > 0)) {
        out.println("Transmission ID: "         + resp.getTransmissionID());
        out.println("<br>");
      }
      // When searching by the eFax Developer transmission identifier
      if ((resp.getDocID() != null) && (resp.getDocID().length() > 0)) {
        out.println("DOC Identifier: "          + resp.getDocID());
        out.println("<br>");
      }
      out.println("<br>Error Level: "           + resp.getErrorLevel());
      out.println("<br>Error Message: "         + resp.getErrorMessage());
      out.println("</blockquote>");
    }
    
    out.println("</body></html>");
    
  }
  
  public void destroy() {
  }
  
}